==> haskell-distributive-0.5.3-11-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-distributive.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: distributive
version: 0.5.3
id: distributive-0.5.3-FetmQwQaxcXKK5vo9ZZR6d
key: distributive-0.5.3-FetmQwQaxcXKK5vo9ZZR6d
license: BSD-3-Clause
copyright: Copyright (C) 2011-2016 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: provisional
homepage: http://github.com/ekmett/distributive/
synopsis: Distributive functors -- Dual to Traversable
description:
    Distributive functors -- Dual to Traversable
category: Data Structures
abi: 86042d6e8705203e681dc0b2bf507441
exposed: True
exposed-modules:
    Data.Distributive Data.Distributive.Generic
import-dirs: /usr/lib/ghc-8.4.3/site-local/distributive-0.5.3
library-dirs: /usr/lib/ghc-8.4.3/site-local/distributive-0.5.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/distributive-0.5.3
hs-libraries: HSdistributive-0.5.3-FetmQwQaxcXKK5vo9ZZR6d
depends:
    base-4.11.1.0 base-orphans-0.7-8MTyiX91Uv15VEKaJjSOuz
    transformers-0.5.5.0
    transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W
    tagged-0.8.5-8zhZJ4AR6AIK89q9NUJ4H
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             base-orphans-0.7-8MTyiX91Uv15VEKaJjSOuz=a151edfe29dad74bae61a4558d90a63b
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W=8fe746d31ebcf312c14c2777ca0f137c
             tagged-0.8.5-8zhZJ4AR6AIK89q9NUJ4H=a77bb2a04ac30650821b1fe6972fa094
haddock-interfaces: /usr/share/doc/haskell-distributive/html/distributive.haddock
haddock-html: /usr/share/doc/haskell-distributive/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-distributive-0.6-2-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-distributive.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: distributive
version: 0.6
id: distributive-0.6-CSsk2h5oLJk84tqIVcz00R
key: distributive-0.6-CSsk2h5oLJk84tqIVcz00R
license: BSD-3-Clause
copyright: Copyright (C) 2011-2016 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: provisional
homepage: http://github.com/ekmett/distributive/
synopsis: Distributive functors -- Dual to Traversable
description:
    Distributive functors -- Dual to @Traversable@
category: Data Structures
abi: 47ee6a4d6f301e390258e1b22ae30dd2
exposed: True
exposed-modules:
    Data.Distributive Data.Distributive.Generic
import-dirs: /usr/lib/ghc-8.4.3/site-local/distributive-0.6
library-dirs: /usr/lib/ghc-8.4.3/site-local/distributive-0.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/distributive-0.6
hs-libraries: HSdistributive-0.6-CSsk2h5oLJk84tqIVcz00R
depends:
    base-4.11.1.0 base-orphans-0.8-K0rU8s5ksIBEF74SEhusR2
    transformers-0.5.5.0 tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             base-orphans-0.8-K0rU8s5ksIBEF74SEhusR2=d7009d493fbbbdb868729a078804cac1
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO=92d44612a64675b8cba7ce44e507a395
haddock-interfaces: /usr/share/doc/haskell-distributive/html/distributive.haddock
haddock-html: /usr/share/doc/haskell-distributive/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
